pub struct LogPageAttributes { /* private fields */ }Implementations
Sourceimpl LogPageAttributes
impl LogPageAttributes
Sourcepub const fn into_bytes(self) -> [u8; 1]
pub const fn into_bytes(self) -> [u8; 1]
Sourcepub const fn from_bytes(bytes: [u8; 1]) -> Self
pub const fn from_bytes(bytes: [u8; 1]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl LogPageAttributes
impl LogPageAttributes
Sourcepub fn per_namespace_smart_log(&self) -> <B1 as Specifier>::InOut
pub fn per_namespace_smart_log(&self) -> <B1 as Specifier>::InOut
Returns the value of per_namespace_smart_log.
Sourcepub fn per_namespace_smart_log_or_err(
&self,
) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
pub fn per_namespace_smart_log_or_err( &self, ) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
Returns the value of per_namespace_smart_log.
Errors
If the returned value contains an invalid bit pattern for per_namespace_smart_log.
Sourcepub fn commands_supported_and_effects(&self) -> <B1 as Specifier>::InOut
pub fn commands_supported_and_effects(&self) -> <B1 as Specifier>::InOut
Returns the value of commands_supported_and_effects.
Sourcepub fn commands_supported_and_effects_or_err(
&self,
) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
pub fn commands_supported_and_effects_or_err( &self, ) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
Returns the value of commands_supported_and_effects.
Errors
If the returned value contains an invalid bit pattern for commands_supported_and_effects.
Sourcepub fn get_log_page(&self) -> <B1 as Specifier>::InOut
pub fn get_log_page(&self) -> <B1 as Specifier>::InOut
Returns the value of get_log_page.
Sourcepub fn get_log_page_or_err(
&self,
) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
pub fn get_log_page_or_err( &self, ) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
Returns the value of get_log_page.
Errors
If the returned value contains an invalid bit pattern for get_log_page.
Sourcepub fn telemetry_host_initiated(&self) -> <B1 as Specifier>::InOut
pub fn telemetry_host_initiated(&self) -> <B1 as Specifier>::InOut
Returns the value of telemetry_host_initiated.
Sourcepub fn telemetry_host_initiated_or_err(
&self,
) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
pub fn telemetry_host_initiated_or_err( &self, ) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
Returns the value of telemetry_host_initiated.
Errors
If the returned value contains an invalid bit pattern for telemetry_host_initiated.
Sourcepub fn persistent_event_log(&self) -> <B1 as Specifier>::InOut
pub fn persistent_event_log(&self) -> <B1 as Specifier>::InOut
Returns the value of persistent_event_log.
Sourcepub fn persistent_event_log_or_err(
&self,
) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
pub fn persistent_event_log_or_err( &self, ) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
Returns the value of persistent_event_log.
Errors
If the returned value contains an invalid bit pattern for persistent_event_log.
Sourcepub fn supported_effects_features_and_nvme_mi(&self) -> <B1 as Specifier>::InOut
pub fn supported_effects_features_and_nvme_mi(&self) -> <B1 as Specifier>::InOut
Returns the value of supported_effects_features_and_nvme_mi.
Sourcepub fn supported_effects_features_and_nvme_mi_or_err(
&self,
) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
pub fn supported_effects_features_and_nvme_mi_or_err( &self, ) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
Returns the value of supported_effects_features_and_nvme_mi.
Errors
If the returned value contains an invalid bit pattern for supported_effects_features_and_nvme_mi.
Sourcepub fn data_area_4(&self) -> <B1 as Specifier>::InOut
pub fn data_area_4(&self) -> <B1 as Specifier>::InOut
Returns the value of data_area_4.
Sourcepub fn data_area_4_or_err(
&self,
) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
pub fn data_area_4_or_err( &self, ) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
Returns the value of data_area_4.
Errors
If the returned value contains an invalid bit pattern for data_area_4.