pub struct OptionalAsyncEventsSupported { /* private fields */ }Implementations
Sourceimpl OptionalAsyncEventsSupported
impl OptionalAsyncEventsSupported
Sourcepub const fn into_bytes(self) -> [u8; 4]
pub const fn into_bytes(self) -> [u8; 4]
Sourcepub const fn from_bytes(bytes: [u8; 4]) -> Self
pub const fn from_bytes(bytes: [u8; 4]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl OptionalAsyncEventsSupported
impl OptionalAsyncEventsSupported
Sourcepub fn namespace_attribute_notices(&self) -> <B1 as Specifier>::InOut
pub fn namespace_attribute_notices(&self) -> <B1 as Specifier>::InOut
Returns the value of namespace_attribute_notices.
Sourcepub fn namespace_attribute_notices_or_err(
&self,
) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
pub fn namespace_attribute_notices_or_err( &self, ) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
Returns the value of namespace_attribute_notices.
Errors
If the returned value contains an invalid bit pattern for namespace_attribute_notices.
Sourcepub fn firmware_activation_notices(&self) -> <B1 as Specifier>::InOut
pub fn firmware_activation_notices(&self) -> <B1 as Specifier>::InOut
Returns the value of firmware_activation_notices.
Sourcepub fn firmware_activation_notices_or_err(
&self,
) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
pub fn firmware_activation_notices_or_err( &self, ) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
Returns the value of firmware_activation_notices.
Errors
If the returned value contains an invalid bit pattern for firmware_activation_notices.
Sourcepub fn asym_namespace_access_change(&self) -> <B1 as Specifier>::InOut
pub fn asym_namespace_access_change(&self) -> <B1 as Specifier>::InOut
Returns the value of asym_namespace_access_change.
Sourcepub fn asym_namespace_access_change_or_err(
&self,
) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
pub fn asym_namespace_access_change_or_err( &self, ) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
Returns the value of asym_namespace_access_change.
Errors
If the returned value contains an invalid bit pattern for asym_namespace_access_change.
Sourcepub fn predictable_latency_event_aggregate_log(
&self,
) -> <B1 as Specifier>::InOut
pub fn predictable_latency_event_aggregate_log( &self, ) -> <B1 as Specifier>::InOut
Returns the value of predictable_latency_event_aggregate_log.
Sourcepub fn predictable_latency_event_aggregate_log_or_err(
&self,
) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
pub fn predictable_latency_event_aggregate_log_or_err( &self, ) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
Returns the value of predictable_latency_event_aggregate_log.
Errors
If the returned value contains an invalid bit pattern for predictable_latency_event_aggregate_log.
Sourcepub fn lba_status_info_alert(&self) -> <B1 as Specifier>::InOut
pub fn lba_status_info_alert(&self) -> <B1 as Specifier>::InOut
Returns the value of lba_status_info_alert.
Sourcepub fn lba_status_info_alert_or_err(
&self,
) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
pub fn lba_status_info_alert_or_err( &self, ) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
Returns the value of lba_status_info_alert.
Errors
If the returned value contains an invalid bit pattern for lba_status_info_alert.
Sourcepub fn endurance_group_event_aggregate_log(&self) -> <B1 as Specifier>::InOut
pub fn endurance_group_event_aggregate_log(&self) -> <B1 as Specifier>::InOut
Returns the value of endurance_group_event_aggregate_log.
Sourcepub fn endurance_group_event_aggregate_log_or_err(
&self,
) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
pub fn endurance_group_event_aggregate_log_or_err( &self, ) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
Returns the value of endurance_group_event_aggregate_log.
Errors
If the returned value contains an invalid bit pattern for endurance_group_event_aggregate_log.
Sourcepub fn normal_nvm_subsystem_shutdown(&self) -> <B1 as Specifier>::InOut
pub fn normal_nvm_subsystem_shutdown(&self) -> <B1 as Specifier>::InOut
Returns the value of normal_nvm_subsystem_shutdown.
Sourcepub fn normal_nvm_subsystem_shutdown_or_err(
&self,
) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
pub fn normal_nvm_subsystem_shutdown_or_err( &self, ) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
Returns the value of normal_nvm_subsystem_shutdown.
Errors
If the returned value contains an invalid bit pattern for normal_nvm_subsystem_shutdown.
Sourcepub fn zone_desc_changed_notices(&self) -> <B1 as Specifier>::InOut
pub fn zone_desc_changed_notices(&self) -> <B1 as Specifier>::InOut
Returns the value of zone_desc_changed_notices.
Sourcepub fn zone_desc_changed_notices_or_err(
&self,
) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
pub fn zone_desc_changed_notices_or_err( &self, ) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
Returns the value of zone_desc_changed_notices.
Errors
If the returned value contains an invalid bit pattern for zone_desc_changed_notices.
Sourcepub fn discovery_log_page_change(&self) -> <B1 as Specifier>::InOut
pub fn discovery_log_page_change(&self) -> <B1 as Specifier>::InOut
Returns the value of discovery_log_page_change.
Sourcepub fn discovery_log_page_change_or_err(
&self,
) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
pub fn discovery_log_page_change_or_err( &self, ) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
Returns the value of discovery_log_page_change.
Errors
If the returned value contains an invalid bit pattern for discovery_log_page_change.