pub struct SglSupport { /* private fields */ }Implementations
Sourceimpl SglSupport
impl SglSupport
Sourceimpl SglSupport
impl SglSupport
Sourcepub const fn into_bytes(self) -> [u8; 4]
pub const fn into_bytes(self) -> [u8; 4]
Sourcepub const fn from_bytes(bytes: [u8; 4]) -> Self
pub const fn from_bytes(bytes: [u8; 4]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl SglSupport
impl SglSupport
Sourcepub fn sgl_address_offset_supported(&self) -> <B1 as Specifier>::InOut
pub fn sgl_address_offset_supported(&self) -> <B1 as Specifier>::InOut
Returns the value of sgl_address_offset_supported.
Sourcepub fn sgl_address_offset_supported_or_err(
&self,
) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
pub fn sgl_address_offset_supported_or_err( &self, ) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
Returns the value of sgl_address_offset_supported.
Errors
If the returned value contains an invalid bit pattern for sgl_address_offset_supported.
Sourcepub fn mptr_sgl_desc_support(&self) -> <B1 as Specifier>::InOut
pub fn mptr_sgl_desc_support(&self) -> <B1 as Specifier>::InOut
Returns the value of mptr_sgl_desc_support.
Sourcepub fn mptr_sgl_desc_support_or_err(
&self,
) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
pub fn mptr_sgl_desc_support_or_err( &self, ) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
Returns the value of mptr_sgl_desc_support.
Errors
If the returned value contains an invalid bit pattern for mptr_sgl_desc_support.
Sourcepub fn lldtl_or_err(
&self,
) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
pub fn lldtl_or_err( &self, ) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
Returns the value of lldtl.
Errors
If the returned value contains an invalid bit pattern for lldtl.
Sourcepub fn mba_or_err(
&self,
) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
pub fn mba_or_err( &self, ) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
Sourcepub fn sbbds_or_err(
&self,
) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
pub fn sbbds_or_err( &self, ) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
Returns the value of sbbds.
Errors
If the returned value contains an invalid bit pattern for sbbds.
Sourcepub fn sdt_or_err(
&self,
) -> Result<<B8 as Specifier>::InOut, InvalidBitPattern<<B8 as Specifier>::Bytes>>
pub fn sdt_or_err( &self, ) -> Result<<B8 as Specifier>::InOut, InvalidBitPattern<<B8 as Specifier>::Bytes>>
Sourcepub fn keyed_datablock_support(&self) -> <B1 as Specifier>::InOut
pub fn keyed_datablock_support(&self) -> <B1 as Specifier>::InOut
Returns the value of keyed_datablock_support.
Sourcepub fn keyed_datablock_support_or_err(
&self,
) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
pub fn keyed_datablock_support_or_err( &self, ) -> Result<<B1 as Specifier>::InOut, InvalidBitPattern<<B1 as Specifier>::Bytes>>
Returns the value of keyed_datablock_support.
Errors
If the returned value contains an invalid bit pattern for keyed_datablock_support.
Sourcepub fn sgl_support(&self) -> <SglSupportType as Specifier>::InOut
pub fn sgl_support(&self) -> <SglSupportType as Specifier>::InOut
Returns the value of sgl_support.
Sourcepub fn sgl_support_or_err(
&self,
) -> Result<<SglSupportType as Specifier>::InOut, InvalidBitPattern<<SglSupportType as Specifier>::Bytes>>
pub fn sgl_support_or_err( &self, ) -> Result<<SglSupportType as Specifier>::InOut, InvalidBitPattern<<SglSupportType as Specifier>::Bytes>>
Returns the value of sgl_support.
Errors
If the returned value contains an invalid bit pattern for sgl_support.