pub struct WriteDword13 { /* private fields */ }Implementations
Sourceimpl WriteDword13
impl WriteDword13
Sourceimpl WriteDword13
impl WriteDword13
Sourcepub const fn into_bytes(self) -> [u8; 4]
pub const fn into_bytes(self) -> [u8; 4]
Sourcepub const fn from_bytes(bytes: [u8; 4]) -> Self
pub const fn from_bytes(bytes: [u8; 4]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl WriteDword13
impl WriteDword13
Sourcepub fn access_frequency(&self) -> <AccessFrequency as Specifier>::InOut
pub fn access_frequency(&self) -> <AccessFrequency as Specifier>::InOut
Returns the value of access_frequency.
Sourcepub fn access_frequency_or_err(
&self,
) -> Result<<AccessFrequency as Specifier>::InOut, InvalidBitPattern<<AccessFrequency as Specifier>::Bytes>>
pub fn access_frequency_or_err( &self, ) -> Result<<AccessFrequency as Specifier>::InOut, InvalidBitPattern<<AccessFrequency as Specifier>::Bytes>>
Returns the value of access_frequency.
Errors
If the returned value contains an invalid bit pattern for access_frequency.
Sourcepub fn with_access_frequency(
self,
new_val: <AccessFrequency as Specifier>::InOut,
) -> Self
pub fn with_access_frequency( self, new_val: <AccessFrequency as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of access_frequency set to the given value.
Panics
If the given value is out of bounds for access_frequency.
Sourcepub fn with_access_frequency_checked(
self,
new_val: <AccessFrequency as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_access_frequency_checked( self, new_val: <AccessFrequency as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of access_frequency set to the given value.
Errors
If the given value is out of bounds for access_frequency.
Sourcepub fn set_access_frequency(
&mut self,
new_val: <AccessFrequency as Specifier>::InOut,
)
pub fn set_access_frequency( &mut self, new_val: <AccessFrequency as Specifier>::InOut, )
Sets the value of access_frequency to the given value.
Panics
If the given value is out of bounds for access_frequency.
Sourcepub fn set_access_frequency_checked(
&mut self,
new_val: <AccessFrequency as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_access_frequency_checked( &mut self, new_val: <AccessFrequency as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of access_frequency to the given value.
Errors
If the given value is out of bounds for access_frequency.
Sourcepub fn access_latency(&self) -> <AccessLatency as Specifier>::InOut
pub fn access_latency(&self) -> <AccessLatency as Specifier>::InOut
Returns the value of access_latency.
Sourcepub fn access_latency_or_err(
&self,
) -> Result<<AccessLatency as Specifier>::InOut, InvalidBitPattern<<AccessLatency as Specifier>::Bytes>>
pub fn access_latency_or_err( &self, ) -> Result<<AccessLatency as Specifier>::InOut, InvalidBitPattern<<AccessLatency as Specifier>::Bytes>>
Returns the value of access_latency.
Errors
If the returned value contains an invalid bit pattern for access_latency.
Sourcepub fn with_access_latency(
self,
new_val: <AccessLatency as Specifier>::InOut,
) -> Self
pub fn with_access_latency( self, new_val: <AccessLatency as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of access_latency set to the given value.
Panics
If the given value is out of bounds for access_latency.
Sourcepub fn with_access_latency_checked(
self,
new_val: <AccessLatency as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_access_latency_checked( self, new_val: <AccessLatency as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of access_latency set to the given value.
Errors
If the given value is out of bounds for access_latency.
Sourcepub fn set_access_latency(
&mut self,
new_val: <AccessLatency as Specifier>::InOut,
)
pub fn set_access_latency( &mut self, new_val: <AccessLatency as Specifier>::InOut, )
Sets the value of access_latency to the given value.
Panics
If the given value is out of bounds for access_latency.
Sourcepub fn set_access_latency_checked(
&mut self,
new_val: <AccessLatency as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_access_latency_checked( &mut self, new_val: <AccessLatency as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of access_latency to the given value.
Errors
If the given value is out of bounds for access_latency.
Sourcepub fn sequenial_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn sequenial_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of sequenial.
Errors
If the returned value contains an invalid bit pattern for sequenial.
Sourcepub fn with_sequenial(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_sequenial(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of sequenial set to the given value.
Panics
If the given value is out of bounds for sequenial.
Sourcepub fn with_sequenial_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_sequenial_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of sequenial set to the given value.
Errors
If the given value is out of bounds for sequenial.
Sourcepub fn set_sequenial(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_sequenial(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of sequenial to the given value.
Panics
If the given value is out of bounds for sequenial.
Sourcepub fn set_sequenial_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_sequenial_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of sequenial to the given value.
Errors
If the given value is out of bounds for sequenial.
Sourcepub fn incompressable(&self) -> <bool as Specifier>::InOut
pub fn incompressable(&self) -> <bool as Specifier>::InOut
Returns the value of incompressable.
Sourcepub fn incompressable_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn incompressable_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of incompressable.
Errors
If the returned value contains an invalid bit pattern for incompressable.
Sourcepub fn with_incompressable(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_incompressable(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of incompressable set to the given value.
Panics
If the given value is out of bounds for incompressable.
Sourcepub fn with_incompressable_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_incompressable_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of incompressable set to the given value.
Errors
If the given value is out of bounds for incompressable.
Sourcepub fn set_incompressable(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_incompressable(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of incompressable to the given value.
Panics
If the given value is out of bounds for incompressable.